Contributor Guidelines
-----------------------

Pull Request Guidelines
~~~~~~~~~~~~~~~~~~~~~~~~

Before you submit a pull request, check that it meets these guidelines:

1. The pull request should include tests.
2. If the pull request adds functionality, the docs should be updated. Put
   your new functionality into a function with a docstring, and add the
   feature to the list in README.rst.
3. The pull request should work for Python 2.6, 2.7, 3.3, and PyPy. Check
   https://travis-ci.org/audreyr/cookiecutter/pull_requests and make sure that
   the tests pass for all supported Python versions.

Coding Standards
~~~~~~~~~~~~~~~~

TODO
